%global bashcompletiondir %(pkg-config --variable=compatdir bash-completion)

%bcond_with bootstrap
%bcond_with java
%bcond_with mingw

Summary:       GIS file format library
Name:          gdal
Version:       3.6.3
Release:       3%{?dist}
License:       MIT
URL:           http://www.gdal.org
Source0:       http://download.osgeo.org/gdal/%{version}/gdal-%{version}.tar.xz
Source1:       http://download.osgeo.org/%{name}/%{version}/%{name}autotest-%{version}.tar.gz

Patch3000:     gdal_utils.patch

BuildRequires: python3-setuptools python3dist(pytest) >= 3.6 python3dist(lxml) >= 4.5.1
BuildRequires: python3-devel python3-numpy
BuildRequires: xz-devel zlib-devel
BuildRequires: qhull-devel sqlite-devel swig unixODBC-devel xerces-c-devel
BuildRequires: openexr-devel openjpeg2-devel pcre2-devel proj-devel >= 5.2.0
BuildRequires: libtirpc-devel libwebp-devel libzstd-devel netcdf-devel ogdi-devel
BuildRequires: liblerc-devel libpng-devel libpq-devel librx-devel libtiff-devel
BuildRequires: json-c-devel libdap-devel libgeotiff-devel libgta-devel libjpeg-devel libkml-devel
BuildRequires: curl-devel expat-devel freexl-devel geos-devel giflib-devel hdf5-devel
BuildRequires: cmake gcc-c++ armadillo-devel bison cfitsio-devel CharLS-devel

%if %{with bootstrap}
BuildRequires: libspatialite-devel mariadb-connector-c-devel poppler-devel
%endif
%if %{with mingw}
BuildRequires: mingw64-python3-setuptools
BuildRequires: mingw32-python3 mingw32-python3-numpy mingw32-python3-setuptools mingw64-python3 mingw64-python3-numpy
BuildRequires: mingw64-openjpeg2 mingw64-pcre2 mingw64-poppler mingw64-postgresql mingw64-proj mingw64-sqlite
BuildRequires: mingw64-liblerc mingw64-libpng mingw64-libspatialite mingw64-libtiff mingw64-libwebp mingw64-openexr
BuildRequires: mingw64-geos mingw64-giflib mingw64-libgeotiff mingw64-libgta mingw64-libjpeg-turbo mingw64-libkml
BuildRequires: mingw64-gcc-c++ mingw64-cfitsio mingw64-curl mingw64-dlfcn mingw64-expat mingw64-freexl
BuildRequires: mingw32-xz-libs mingw32-zlib mingw32-zstd mingw64-filesystem >= 102
BuildRequires: mingw32-pcre2 mingw32-poppler mingw32-postgresql mingw32-proj mingw32-sqlite mingw32-xerces-c
BuildRequires: mingw32-libpng mingw32-libspatialite mingw32-libtiff mingw32-libwebp mingw32-openexr mingw32-openjpeg2
BuildRequires: mingw32-giflib mingw32-libgeotiff mingw32-libgta mingw32-libjpeg-turbo mingw32-libkml mingw32-liblerc
BuildRequires: mingw32-cfitsio mingw32-curl mingw32-dlfcn mingw32-expat mingw32-freexl mingw32-geos
BuildRequires: mingw32-filesystem >= 102 mingw32-gcc-c++
BuildRequires: mingw64-xerces-c mingw64-xz-libs mingw64-zlib mingw64-zstd
%endif
%if %{with java}
BuildRequires: ant
BuildRequires: java-devel >= 1.6.0
BuildRequires: javapackages-local
BuildRequires: jpackage-utils
%endif

Requires: gpsbabel %{name}-libs = %{version}-%{release}

%description
GDAL is a translator library for raster and vector geospatial data
formats that is released under an MIT style Open Source License by
the Open Source Geospatial Foundation. As a library, it presents a
single raster abstract data model and single vector abstract data
model to the calling application for all supported formats. It also
comes with a variety of useful command line utilities for data translation
and processing.


%package devel
Summary:       Development files for the GDAL file format library
Requires:      %{name}-libs = %{version}-%{release}

%description devel
This package contains development files for GDAL.


%package libs
Summary:       GDAL file format library
Provides:      bundled(g2lib) = 1.6.0
Provides:      bundled(degrib) = 2.14

%description libs
This package contains the GDAL file format library.

%if %{with mingw}
%package -n mingw32-%{name}
Summary:       MinGW Windows GDAL library
Provides:      bundled(g2lib) = 1.6.0
Provides:      bundled(degrib) = 2.14
BuildArch:     noarch

%description -n mingw32-%{name}
MinGW Windows GDAL library.


%package -n mingw32-%{name}-tools
Summary:       MinGW Windows GDAL library tools
BuildArch:     noarch

%description -n mingw32-%{name}-tools
MinGW Windows GDAL library tools.


%package -n mingw64-%{name}
Summary:       MinGW Windows GDAL library
Provides:      bundled(g2lib) = 1.6.0
Provides:      bundled(degrib) = 2.14
BuildArch:     noarch

%description -n mingw64-%{name}
MinGW Windows GDAL library.


%package -n mingw64-%{name}-tools
Summary:       MinGW Windows GDAL library tools
BuildArch:     noarch

%description -n mingw64-%{name}-tools
MinGW Windows GDAL library tools.
%endif

%if %{with java}
%package java
Summary:        Java modules for the GDAL file format library
Requires:       jpackage-utils
Requires:       %{name}-libs = %{version}-%{release}

%description java
The GDAL Java modules provide support to handle multiple GIS file formats.


%package javadoc
Summary:        Javadocs for %{name}
Requires:       jpackage-utils
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.
%endif


%package -n python3-gdal
Summary:        Python modules for the GDAL file format library
Requires:       python3-numpy
Requires:       %{name}-libs = %{version}-%{release}

%description -n python3-gdal
The GDAL Python 3 modules provide support to handle multiple GIS file formats.


%package python-tools
Summary:        Python tools for the GDAL file format library
Requires:       python3-gdal

%description python-tools
The GDAL Python package provides number of tools for programming and
manipulating GDAL file format library


%if %{with mingw}
%package -n mingw32-python3-%{name}
Summary:       MinGW Windows Python3 GDAL bindings

%description -n mingw32-python3-%{name}
MinGW Windows Python3 GDAL bindings.


%package -n mingw64-python3-%{name}
Summary:       MinGW Windows Python3 GDAL bindings

%description -n mingw64-python3-%{name}
MinGW Windows Python3 GDAL bindings.
%endif

%global __provides_exclude_from ^%{python3_sitearch}/.*\.so$


%if %{with mingw}
%{?mingw_debug_package}
%endif

%prep
%autosetup -N

rm data/cubewerx_extra.wkt
rm data/esri_StatePlane_extra.wkt
rm data/ecw_cs.wkt


sed -i 's|data/cubewerx_extra.wkt||' gdal.cmake
sed -i 's|data/esri_StatePlane_extra.wkt||' gdal.cmake
sed -i 's|data/ecw_cs.wkt||' gdal.cmake

rm -rf frmts/zlib
rm -rf frmts/png/libpng
rm -rf frmts/gif/giflib
rm -rf frmts/jpeg/libjpeg
rm -rf frmts/jpeg/libjpeg12
rm -rf frmts/gtiff/libgeotiff
rm -rf frmts/gtiff/libtiff
rm -rf mrf/LERCV1
rm -rf third_party/LercLib

tar xf %{SOURCE1}
mv %{name}autotest-%{version} autotest

%autopatch -p1


%build
%cmake \
  -DCMAKE_INSTALL_INCLUDEDIR=include/gdal \
  -DGDAL_JAVA_INSTALL_DIR=%{_jnidir}/%{name} \
  -DGDAL_USE_JPEG12_INTERNAL=OFF
%cmake_build

%if %{with mingw}
%mingw_cmake \
  -DCMAKE_INSTALL_INCLUDEDIR=include/gdal \
  -DGDAL_USE_JPEG12_INTERNAL=OFF
%mingw_make_build
%endif


%install
%cmake_install

%if %{with mingw}
%mingw_make_install
rm -r %{buildroot}%{mingw32_datadir}
rm -r %{buildroot}%{mingw64_datadir}
%endif

for file in %{buildroot}%{_bindir}/*.py; do
  if [ -f %{buildroot}%{_mandir}/man1/`basename ${file/.py/.1*}` ]; then
    echo "%{_mandir}/man1/`basename ${file/.py/.1*}`" >> gdal_python_manpages.txt
    echo "%exclude %{_mandir}/man1/`basename ${file/.py/.1*}`" >> gdal_python_manpages_excludes.txt
  fi
done


%if %{with mingw}
%mingw_debug_install_post
%endif


%check
%ctest || :


%files -f gdal_python_manpages_excludes.txt
%{_bindir}/8211*
%{_bindir}/gdal_contour
%{_bindir}/gdal_create
%{_bindir}/gdal_grid
%{_bindir}/gdal_rasterize
%{_bindir}/gdal_translate
%{_bindir}/gdal_viewshed
%{_bindir}/gdaladdo
%{_bindir}/gdalbuildvrt
%{_bindir}/gdaldem
%{_bindir}/gdalenhance
%{_bindir}/gdalinfo
%{_bindir}/gdallocationinfo
%{_bindir}/gdalmanage
%{_bindir}/gdalmdiminfo
%{_bindir}/gdalmdimtranslate
%{_bindir}/gdalsrsinfo
%{_bindir}/gdaltindex
%{_bindir}/gdaltransform
%{_bindir}/gdalwarp
%{_bindir}/gnmanalyse
%{_bindir}/gnmmanage
%{_bindir}/nearblack
%{_bindir}/ogr2ogr
%{_bindir}/ogrinfo
%{_bindir}/ogrlineref
%{_bindir}/ogrtindex
%{_bindir}/s57dump
%{_datadir}/bash-completion/completions/*
%exclude %{_datadir}/bash-completion/completions/*.py
%{_mandir}/man1/*
%exclude %{_mandir}/man1/gdal-config.1*

%files libs
%license LICENSE.TXT
%doc NEWS.md PROVENANCE.TXT COMMITTERS
%{_libdir}/libgdal.so.32
%{_libdir}/libgdal.so.32.*
%{_datadir}/%{name}/
%{_libdir}/gdalplugins/

%files devel
%{_bindir}/%{name}-config
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/gdal/
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man1/gdal-config.1*

%if %{with mingw}
%files -n mingw32-%{name}
%license LICENSE.TXT
%{mingw32_bindir}/libgdal-32.dll
%{mingw32_bindir}/gdal-config
%{mingw32_libdir}/libgdal.dll.a
%{mingw32_libdir}/cmake/gdal/
%{mingw32_libdir}/pkgconfig/gdal.pc
%{mingw32_libdir}/gdalplugins/
%{mingw32_includedir}/%{name}/

%files -n mingw32-%{name}-tools
%{mingw32_bindir}/*.exe

%files -n mingw64-%{name}
%license LICENSE.TXT
%{mingw64_bindir}/libgdal-32.dll
%{mingw64_bindir}/gdal-config
%{mingw64_libdir}/libgdal.dll.a
%{mingw64_libdir}/cmake/gdal/
%{mingw64_libdir}/pkgconfig/gdal.pc
%{mingw64_libdir}/gdalplugins/
%{mingw64_includedir}/%{name}/

%files -n mingw64-%{name}-tools
%{mingw64_bindir}/*.exe
%endif

%files -n python3-gdal
%doc swig/python/README.rst
%{python3_sitearch}/GDAL-%{version}-py*.egg-info/
%{python3_sitearch}/osgeo/
%{python3_sitearch}/osgeo_utils/

%files python-tools -f gdal_python_manpages.txt
%{_bindir}/gdal_calc.py
%{_bindir}/gdal_edit.py
%{_bindir}/gdal_fillnodata.py
%{_bindir}/gdal_merge.py
%{_bindir}/gdal_pansharpen.py
%{_bindir}/gdal_polygonize.py
%{_bindir}/gdal_proximity.py
%{_bindir}/gdal_retile.py
%{_bindir}/gdal_sieve.py
%{_bindir}/gdal2tiles.py
%{_bindir}/gdal2xyz.py
%{_bindir}/gdalattachpct.py
%{_bindir}/gdalcompare.py
%{_bindir}/gdalmove.py
%{_bindir}/ogr_layer_algebra.py
%{_bindir}/ogrmerge.py
%{_bindir}/pct2rgb.py
%{_bindir}/rgb2pct.py
%{_datadir}/bash-completion/completions/*.py

%if %{with mingw}
%files -n mingw32-python3-%{name}
%{mingw32_bindir}/*.py
%{mingw32_python3_sitearch}/GDAL-%{version}-py%{mingw32_python3_version}.egg-info/
%{mingw32_python3_sitearch}/osgeo/
%{mingw32_python3_sitearch}/osgeo_utils/

%files -n mingw64-python3-%{name}
%{mingw64_bindir}/*.py
%{mingw64_python3_sitearch}/GDAL-%{version}-py%{mingw32_python3_version}.egg-info/
%{mingw64_python3_sitearch}/osgeo/
%{mingw64_python3_sitearch}/osgeo_utils/
%endif

%if %{with java}
%files java
%{_jnidir}/%{name}/gdal-%{version}-sources.jar
%{_jnidir}/%{name}/gdal-%{version}.jar
%{_jnidir}/%{name}/gdal-%{version}.pom
%{_jnidir}/%{name}/libgdalalljni.so

%files javadoc
%{_jnidir}/%{name}/gdal-%{version}-javadoc.jar
%endif


%changelog
* Wed Aug 02 2023 kianli <kianli@tencent.com> - 3.6.3-3
- Rebuilt for libtiff 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.3-2
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 27 2023 cunshunxia <cunshunxia@tencent.com> - 3.6.3-1
- initial build
